@@ -40,9 +40,7 @@ def mpv(entry, rpc_client=None):
     hist_class.write_hist()
 
     if config.dc_presence:
-        dc_media_title = (
-            f"{entry.show_name} - {entry.quality} | {entry.ep}/{entry.latest_ep}"
-        )
+        dc_media_title = f"{entry.show_name} | {entry.ep}/{entry.latest_ep}"
         dc_presence(dc_media_title, entry.category_url, rpc_client)
 
     return sub_proc
